@@ -1,5 +1,5 @@
 package Test::Selenium::Remote::Driver;
-$Test::Selenium::Remote::Driver::VERSION = '1.42';
+$Test::Selenium::Remote::Driver::VERSION = '1.44';
 # ABSTRACT: Useful testing subclass for Selenium::Remote::Driver
 
 use Moo;
@@ -90,15 +90,15 @@ sub BUILD {
 
 =head1 NAME
 
-Test::Selenium::Remote::Driver
+Test::Selenium::Remote::Driver - add testing methods to L<Selenium::Remote::Driver>
 
 =head1 DESCRIPTION
 
-A subclass of L<Selenium::Remote::Driver>.  which provides useful testing
-functions.
+A subclass of L<Selenium::Remote::Driver> which provides useful testing
+methods.
 
 This is an I<experimental> addition to the Selenium::Remote::Driver
-distribution, and some interfaces may change.
+distribution. Some interfaces may change.
 
 =head1 Methods
 
@@ -106,17 +106,24 @@ distribution, and some interfaces may change.
 
 This will create a new Test::Selenium::Remote::Driver object, which subclasses
 L<Selenium::Remote::Driver>.  This subclass provides useful testing
-functions.  It is modeled on L<Test::WWW::Selenium>.
+functions. It is modeled on L<Test::WWW::Selenium>.
 
 Environment vars can be used to specify options to pass to
 L<Selenium::Remote::Driver>. ENV vars are prefixed with C<TWD_>.
-( After the old fork name, "Test::WebDriver" )
+( After the old fork name, "Test::WebDriver" ). The explicity passed
+options have precedence. ENV vars take only effect when they are
+actually set. This important e.g. for the option C<javascript>, which
+is turned on per default in L<Selenium::Remote::Driver>.
 
 Set the Selenium server address with C<$TWD_HOST> and C<$TWD_PORT>.
 
 Pick which browser is used using the  C<$TWD_BROWSER>, C<$TWD_VERSION>,
 C<$TWD_PLATFORM>, C<$TWD_JAVASCRIPT>, C<$TWD_EXTRA_CAPABILITIES>.
 
+C<$TWD_BROWSER> is actually an alias for C<$TWD_BROWSER_NAME>.
+C<$TWD_HOST> is actually an alias for C<$TWD_REMOTE_SERVER_ADDR>.
+The aliases habe lower precedence than the original values.
+
 See L<Selenium::Remote::Driver> for the meanings of these options.
 
 =for Pod::Coverage BUILDARGS
@@ -126,15 +133,20 @@ See L<Selenium::Remote::Driver> for the meanings of these options.
 sub BUILDARGS {
     my ( undef, %p ) = @_;
 
+    OPT:
     for my $opt (
         qw/remote_server_addr port browser_name version platform
         javascript auto_close extra_capabilities/
       )
     {
-        $p{$opt} //= $ENV{ 'TWD_' . uc($opt) };
+        my $env_var_name = 'TWD_' . uc($opt);
+
+        next OPT unless exists $ENV{$env_var_name};
+
+        $p{$opt} //= $ENV{$env_var_name};
     }
-    $p{browser_name}       //= $ENV{TWD_BROWSER};                      # ykwim
-    $p{remote_server_addr} //= $ENV{TWD_HOST};                         # ykwim
+    $p{browser_name}       //= $ENV{TWD_BROWSER} if exists $ENV{TWD_BROWSER};  # ykwim
+    $p{remote_server_addr} //= $ENV{TWD_HOST}    if exists $ENV{TWD_HOST};     # ykwim
     $p{webelement_class}   //= 'Test::Selenium::Remote::WebElement';
     return \%p;
 }
@@ -150,10 +162,10 @@ has verbose => ( is => 'rw', );
 =head2 server_is_running( $host, $port )
 
 Returns true if a Selenium server is running.  The host and port
-parameters are optional, and default to C<localhost:4444>.
+parameters are optional, and they default to C<localhost:4444>.
 
-Environment vars C<TWD_HOST> and C<TWD_PORT> can also be used to
-determine the server to check.
+The environment vars C<TWD_HOST> and C<TWD_PORT> can also be used to
+determine which server should be checked.
 
 =cut
 
@@ -220,11 +232,11 @@ output if you do not handle it properly.
 
 =head1 Testing Methods
 
-The following testing methods are available. For
-more documentation, see the related test methods in L<Selenium::Remote::Driver>
+The following testing methods are available.
+For more documentation, see the related methods in L<Selenium::Remote::Driver>.
 (And feel free to submit a patch to flesh out the documentation for these here).
 Defaults for optional arguments B<should> be the same as for their analogues in
-L<Selenium::Remote::Driver> and L<Selenium::Remote::WebElement>.
+L<Selenium::Remote::Driver>.
 
     alert_text_is
     alert_text_isnt
@@ -559,12 +571,12 @@ sub content_unlike {
 
 Tells if the text of the page (as returned by C<< get_body() >>)  matches
 I<$regex>. If an arrayref of regex's are provided, one 'test' is run for each
-regex against the content of the current page.
+regex against the text of the current page.
 
-A default description of 'Content is like "$regex"' will be provided if there
+A default description of 'Text is like "$regex"' will be provided if there
 is no description.
 
-To also match the HTML see, C<< content_unlike() >>.
+To also match the HTML, see C<< content_unlike() >>.
 
 =cut
 
@@ -603,14 +615,14 @@ sub body_text_like {
    $twd->body_text_unlike( [$regex_1, $regex_2] [, $desc ] )
 
 Tells if the text of the page (as returned by C<< get_body() >>)
- does NOT match I<$regex>. If an arrayref of regex's
-are provided, one 'test' is run for each regex against the content of the
+does NOT match I<$regex>. If an arrayref of regex's
+are provided, one 'test' is run for each regex against the text of the
 current page.
 
 A default description of 'Text is unlike "$regex"' will be provided if there
 is no description.
 
-To also match the HTML see, C<< content_unlike() >>.
+To also match the HTML, see C<< content_unlike() >>.
 
 =cut
 
@@ -651,7 +663,7 @@ sub body_text_unlike {
    $twd->content_contains( $str [, $desc ] )
    $twd->content_contains( [$str_1, $str_2] [, $desc ] )
 
-Tells if the content of the page contains I<$str>. If an arrayref of strngs's
+Tells if the content of the page contains I<$str>. If an arrayref of strings
 are provided, one 'test' is run for each string against the content of the
 current page.
 
@@ -740,12 +752,12 @@ sub content_lacks {
 
 Tells if the text of the page (as returned by C<< get_body() >>) contains
 I<$str>. If an arrayref of strings are provided, one 'test' is run for each
-regex against the content of the current page.
+string against the text of the current page.
 
 A default description of 'Text contains "$str"' will be provided if there
 is no description.
 
-To also match the HTML see, C<< content_uncontains() >>.
+To also match the HTML, see C<< content_lacks() >>.
 
 =cut
 
@@ -784,14 +796,14 @@ sub body_text_contains {
    $twd->body_text_lacks( [$str_1, $str_2] [, $desc ] )
 
 Tells if the text of the page (as returned by C<< get_body() >>)
- does NOT contain I<$str>. If an arrayref of strings
-are provided, one 'test' is run for each regex against the content of the
+does NOT contain I<$str>. If an arrayref of strings
+are provided, one 'test' is run for each string against the content of the
 current page.
 
 A default description of 'Text lacks "$str"' will be provided if there
 is no description.
 
-To also match the HTML see, C<< content_lacks() >>.
+To also match the HTML, see C<< content_lacks() >>.
 
 =cut
 
